<?php

namespace Drupal\contact_permissions;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\user\Entity\Role;
use Drupal\user\RoleInterface;

/**
 * Provides the permissions for accessing per role contact forms.
 */
class ContactPermissionsPermissions {

  use StringTranslationTrait;

  /**
   * Get access per role contact forms permissions.
   *
   * @return array
   *   Permissions array.
   */
  public function permissions() {
    // Generate permissions for each user role.
    $permissions = [];

    /** @var \Drupal\user\RoleInterface[] $roles */
    $roles = Role::loadMultiple();
    unset($roles[RoleInterface::ANONYMOUS_ID]);

    if (count($roles) < 1) {
      return $permissions;
    }

    foreach ($roles as $role) {
      $permissions["use {$role->id()} personal contact forms"] = [
        'title' => $this->t("Use %role_name's personal contact forms", ['%role_name' => $role->label()]),
      ];
    }

    return $permissions;
  }

}
